<?php

/**
 * 2007-2024 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2024 PrestaShop SA
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

require_once ROOT_URL . '/services/api/BoldAPI.php';

class BoldWebhooksController
{
    private $bold_api_client;

    public function __construct(){
        $this->bold_api_client = BoldAPI::getInstance();
    }

    public function isWebhookConfigured($webhook_url, $api_key)
    {
        try {
            // Asegúrate de que $bold_api_client esté correctamente inicializado
            $remote_webhooks = $this->bold_api_client->getListWebhooks($api_key);
            
            if (gettype($remote_webhooks) == 'boolean' && $remote_webhooks) {
                return '';
            } else if (is_array($remote_webhooks)) {
                $filtered_webhooks = array_filter($remote_webhooks, function($webhook) use ($webhook_url) {
                    return $webhook['url'] === $webhook_url;
                });
                if (count($filtered_webhooks) == 0) {
                    return 'Tu webhook aún no está configurado, inicia sesión en Bold y configura el webhook ' . $webhook_url;
                }else{
                    return '';
                }
            } else {
                return 'No tienes ningún webhook configurado, inicia sesión en Bold y configura el webhook ' . $webhook_url;
            }
        } catch (\Throwable $th) {
            return $th->getMessage();
        }
    }
}
 