<?php
/**
* 2007-2024 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2024 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

require_once ROOT_URL.'/services/model/Constants.php';
require_once ROOT_URL.'/services/api/BoldAPI.php';
require_once ROOT_URL.'/services/order/CheckoutOrderManager.php';

class BoldConfirmationModuleFrontController extends ModuleFrontController
{

    public function postProcess()
    {
        if (!Tools::isSubmit(BoldCheckoutParam::REFERENCE))  {
            $this->redirectError('Error getting data from Bold checkout');
        }
        BoldLog::generate("Capturando datos de respuesta", 'info');
        $bold_cart_id = Tools::getValue(BoldCheckoutParam::REFERENCE);
        $bold_status = strtoupper(Tools::getValue(BoldCheckoutParam::BOLD_STATUS , ""));

        if ($bold_status == BoldTxStatus::FAILED)
        {
            $this->redirectError('Hubo un error al confirmar el pago, intente de nuevo... ');
        }
        if ($bold_status == BoldTxStatus::REJECTED)
        {
            $this->redirectError('Tu transacción ha sido rechazadaa intenta de nuevo');
        }
        $cart_id = $this->getCartIdFromBold($bold_cart_id);
        BoldLog::generate("Cargando carrito ".$bold_cart_id." carrito:".$cart_id, 'info');
        $cart = new Cart((int) $cart_id);

        $order = $this->createOrder($cart,$bold_cart_id);

        $this->redirectOrderConfirmation($cart, $order);

    }

    private function getCartIdFromBold($bold_cart_id)
    {
        $bold_id_split = explode("-", $bold_cart_id);
        return end($bold_id_split);
    }

    public function createOrder($cart, $bold_cart_id)
    {
        BoldLog::generate("Creando orden en prestahop", 'info');

        $order_manager = new CheckoutOrderManager($cart,$bold_cart_id);
        $order_manager->createCheckoutOrder();

        $orderId = Order::getIdByCartId($cart->id);
        $order = new Order($orderId);

        return $order;
    }

    public function redirectOrderConfirmation($cart, $order)
    {
        $url = __PS_BASE_URI__ . 'index.php?controller=order-confirmation';
        $url .= '&key=' . $order->secure_key;
        $url .= '&total=' . $cart->getOrderTotal();
        $url .= '&id_cart=' . $order->id_cart;
        $url .= '&id_order=' . $order->id;
        $url .= '&id_module=' . $this->module->id;

        return Tools::redirect($url);
    }

    public function redirectError($message)
    {
        BoldLog::generate($message, 'error');
        $this->context->cookie->__set('error_message', $message);
        Tools::redirect('index.php?controller=order&step=3&typeReturn=bold-failure');
    }


}
