<?php
/**
* 2007-2024 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author    PrestaShop SA <contact@prestashop.com>
*  @copyright 2007-2024 PrestaShop SA
*  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

include_once ROOT_URL.'/services/model/Constants.php';
include_once ROOT_URL.'/services/checkout/BoldCheckout.php';
class BoldPreprocessModuleFrontController extends ModuleFrontController
{
    /**
     * Do whatever you have to before redirecting the customer on the website of your payment processor.
     */
    public function postProcess()
    {
        /*
         * Oops, an error occured.
         */
        if (Tools::getValue('action') == 'error') {
            return $this->displayError('An error occurred while trying to redirect the customer');
        } else {

            $cart = Context::getContext()->cart;
            $checkout = new BoldCheckout();

            $redirect_url = $this->context->link->getModuleLink(BoldModule::MODULE_NAME, 'confirmation', array(), true);
            $origin_url = $this->context->link->getPageLink('order', true, null ,array('step'=>'3') ,false);
            $checkout_data = $checkout->getDataFromCart($cart);
            $urls_data = array(
                'boldco_return_url' => $redirect_url,
                'boldco_origin_url' => $origin_url,
            );
            $checkout_data += $urls_data;
            $this->context->smarty->assign($checkout_data);
            return $this->setTemplate('module:bold/views/templates/front/redirect_to_checkout.tpl');
        }
    }


    protected function displayError($message, $description = false)
    {
        /*
         * Create the breadcrumb for your ModuleFrontController.
         */
        $this->context->smarty->assign('path', '
			<a href="' . $this->context->link->getPageLink('order', null, null, 'step=3') . '">' . $this->module->l('Payment') . '</a>
			<span class="navigation-pipe">&gt;</span>' . $this->module->l('Error'));

        /*
         * Set error message and description for the template.
         */
        array_push($this->errors, $this->module->l($message), $description);

        return $this->setTemplate('error.tpl');
    }
}
