<?php

/**
 * 2007-2024 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 * @author    PrestaShop SA <contact@prestashop.com>
 * @copyright 2007-2024 PrestaShop SA
 * @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

require_once ROOT_URL . '/services/model/Constants.php';
require_once ROOT_URL . '/services/api/BoldAPI.php';
require_once ROOT_URL . '/services/order/WebhookOrderManager.php';

class BoldWebhookModuleFrontController extends ModuleFrontController
{

    public function postProcess()
    {

        BoldLog::generate("Capturando datos de webhook", 'info');
        $data = json_decode(file_get_contents('php://input'), true);

        if (empty($data)){
            $this->redirectError('Error getting data from Bold checkout');
        }
        $bold_cart_id = $data['data']['metadata']['reference'];
        $cart_id = $this->getCartIdFromBold($bold_cart_id);

        BoldLog::generate("Cargando carrito " . $bold_cart_id . " carrito:" . $cart_id, 'info');
        $cart = new Cart((int)$cart_id);

        $order = $this->createOrder($cart, $data);

        $this->redirectOrderConfirmation($cart, $order);

    }

    public function createOrder($cart, $data)
    {
        BoldLog::generate("Creando orden en prestahop", 'info');

        $order_manager = new WebhookOrderManager($cart, $data);
        $order_manager->createWebhookOrder();

        $orderId = Order::getIdByCartId($cart->id);
        $order = new Order($orderId);

        return $order;
    }

    public function redirectOrderConfirmation($cart, $order)
    {
        $url = __PS_BASE_URI__ . 'index.php?controller=order-confirmation';
        $url .= '&key=' . $order->secure_key;
        $url .= '&total=' . $cart->getOrderTotal();
        $url .= '&id_cart=' . $order->id_cart;
        $url .= '&id_order=' . $order->id;
        $url .= '&id_module=' . $this->module->id;

        return Tools::redirect($url);
    }

    public function redirectError($message)
    {
        BoldLog::generate($message, 'error');
        $this->context->smarty->assign(array("error_message" => $message));
        Tools::redirect('index.php?controller=order&step=3&typeReturn=failure');
    }

    private function getCartIdFromBold($bold_cart_id)
    {
        $bold_id_split = explode("-", $bold_cart_id);
        return end($bold_id_split);
    }
}
