<?php


require_once ROOT_URL.'/services/BoldLog.php';
require_once ROOT_URL.'/services/model/Constants.php';

class BoldAPI
{

    const VOUCHER = '/v2/payment-voucher/';

    public static function getinstance()
    {
        static $bold_api = null;
        if (null === $bold_api) {
            $bold_api = new BoldAPI();
        }
        return $bold_api;
    }

    public function getTransactionVoucher ($reference)
    {
        $endpoint=BoldPaymentEnv::getUrl().self::VOUCHER.$reference;
        $curl = curl_init();

        curl_setopt($curl, CURLOPT_URL, $endpoint);
        curl_setopt($curl, CURLOPT_USERAGENT, 'Bold Prestashop v'.BOLD_VERSION);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
        curl_setopt($curl, CURLOPT_HTTPHEADER, $this->getHeaders());

        $response = curl_exec($curl);

        $http_status = strval(curl_getinfo($curl, CURLINFO_RESPONSE_CODE));
        // Comprobar si hay errores
        if($response === false) {
            $error = curl_error($curl);
            curl_close($curl);
            BoldLog::generate("Error consumiendo servicio voucher:" .$error);
            return;
        }

        if ($http_status != 200){
            curl_close($curl);
            BoldLog::generate("Error consumiendo servicio voucher: status". $http_status);
            return;
        }
        curl_close($curl);
        $json_response = json_decode($response, true);
        BoldLog::generate("Creando voucher", 'info');
        return $json_response ;
    }

    public function getListWebhooks($api_key = '')
    {
        $endpoint = BoldWebhookEnv::getUrl();
        $curl = curl_init();

        curl_setopt($curl, CURLOPT_URL, $endpoint);
        curl_setopt($curl, CURLOPT_USERAGENT, 'Bold Prestashop v'.BOLD_VERSION);
        curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($curl, CURLOPT_CUSTOMREQUEST, 'GET');
        curl_setopt($curl, CURLOPT_HTTPHEADER, array(
            "Authorization: x-api-key ".($api_key??$this->getAuthKey()),
            'Accept: application/json',
            'Content-Type: application/json',
        ));

        $response = curl_exec($curl);

        $http_status = strval(curl_getinfo($curl, CURLINFO_RESPONSE_CODE));
        // Comprobar si hay errores
        if($response === false) {
            $error = curl_error($curl);
            curl_close($curl);
            BoldLog::generate("Error consumiendo servicio webhooks:" .$error);
            return true;
        }

        if ($http_status == 403){
            curl_close($curl);
            BoldLog::generate("Error consumiendo servicio webhooks: status ". $http_status, 'warning');
            throw new Exception("Tus llaves de identidad y secreta son invalidas, revisa la información.", 403);
            
        }else if ($http_status != 200){
            curl_close($curl);
            BoldLog::generate("Error consumiendo servicio webhooks: status ". $http_status, 'error');
            return true;
        }
        curl_close($curl);
        $json_response = json_decode($response, true);
        BoldLog::generate("Listando webhooks", 'info');
        return $json_response;
    }

    private function getHeaders(){
        return array(
            "Authorization: x-api-key ".$this->getAuthKey(),
            'Accept: application/json',
            'Content-Type: application/json',
        );
    }

    private function getAuthKey(){
        $is_sandbox = Configuration::get('BOLD_TEST_MODE');
        $auth_token = $is_sandbox ? Configuration::get('BOLD_TEST_API_KEY') : Configuration::get('BOLD_API_KEY');
        return $auth_token;
    }

}
