<?php

require_once ROOT_URL.'/services/model/Constants.php';
require_once ROOT_URL.'/services/checkout/Checkout.php';
require_once ROOT_URL.'/services/order/BoldOrderManager.php';

class BoldCheckout extends Checkout
{

   public function getDataFromCart($cart)
   {

       $currency = new Currency($cart->id_currency);
       $customer = new Customer($cart->id_customer);
       $billing_address = new Address($cart->id_address_invoice);

       $currency_code = $currency->iso_code;

       $is_sandbox = Configuration::get('BOLD_TEST_MODE');

       $auth_token = $is_sandbox ? Configuration::get('BOLD_TEST_API_KEY') : Configuration::get('BOLD_API_KEY');
       $secret_key  = $is_sandbox ?  Configuration::get('BOLD_TEST_SECRET_KEY') : Configuration::get('BOLD_SECRET_KEY');
       $bold_prefix  = Configuration::get('BOLD_PREFIX');
       $order_reference = empty($bold_prefix) ?  "BOLD-".$cart->id : $bold_prefix."-".$cart->id;
       $order_reference = $is_sandbox ? 'test-'.$order_reference : $order_reference ;

       $amount_in_cents = $cart->getOrderTotal();

       $signature = hash("sha256","{$order_reference}{$amount_in_cents}{$currency_code}{$secret_key}");

       $this->createBoldTx($cart->id, $amount_in_cents,$cart->id_customer,BoldTxStatus::PENDING,$is_sandbox);

       return array(
           'boldco_auth_token' => $auth_token,
           'boldco_amount_in_cents' => $amount_in_cents,
           "boldco_currency" => $currency_code,
           'boldco_order_reference' => $order_reference,
           'boldco_signature' => $signature,
           'boldco_script_url' => BoldScriptEnv::getUrl(),
           'boldco_integration_type' => 'prestashop-'.BOLD_VERSION,
           'boldco_customer_data'=> $this->getCustomerData($customer, $billing_address),
           'boldco_billing_address' => $this->getBillingData($billing_address)
       );
   }

   private function getCustomerData($customer, $billing_address)
   {
    return json_encode(array(
                          "email" => $customer->email,
                          "fullName" => $customer->firstname." ".$customer->lastname,
                          "phone" => $billing_address->phone,
                      ));
   }

   private function getBillingData($billing_address)
   {
   $country = new Country($billing_address->id_country);
   $state = new State($billing_address->id_state);
   return json_encode(array(
                          "address" => $billing_address->address1,
                          "zipCode" => $billing_address->postcode,
                          "city" => $billing_address->city,
                          "state" => $state->iso_code,
                          "country" => $country->iso_code,
                      ));
      }

   public function createBoldTx($cart_id, $amount, $customer_id, $payment_status, $is_payment_test)
   {
       $bold_manager = new BoldOrderManager();
       $bold_manager->createOrder($cart_id, $amount, $customer_id, $payment_status, $is_payment_test);
   }






}